@@ -15,15 +15,15 @@
 
 #include <config-kalzium.h>
 
-#include <QFont>
-#include <QRect>
-#include <QPainter>
 #include <QDebug>
+#include <QFont>
+#include <QPainter>
+#include <QRect>
 
 #include <KLocalizedString>
+#include <KUnitConversion/Converter>
 
 #include <element.h>
-#include <kunitconversion/converter.h>
 
 #include "prefs.h"
 
@@ -159,7 +159,7 @@ QString KalziumUtils::prettyUnit(const Element* el, ChemicalDataObject::BlueObel
     case ChemicalDataObject::oxidation:
     {
         QStringList oxidationList = el->dataAsString(kind).split(',');
-        result = oxidationList.join(", ");
+        result = oxidationList.join(QStringLiteral(", "));
         break;
     }
     default:
